==> haskell-postgresql-libpq-0.9.4.3-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-libpq
version:              0.9.4.3
visibility:           public
id:                   postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
key:                  postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/haskellari/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  cd9b8a541948660572217652630d9e59
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

hidden-modules:       Database.PostgreSQL.LibPQ.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/postgresql-libpq-0.9.4.3
library-dirs:
    /usr/lib/ghc-9.2.8/site-local/postgresql-libpq-0.9.4.3 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/haskell-postgresql-libpq
hs-libraries:         HSpostgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.16.4.0 bytestring-0.11.4.0 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-libpq-0.9.4.3-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-libpq
version:              0.9.4.3
visibility:           public
id:                   postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
key:                  postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/haskellari/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  8df58618391c4fefbe503d6ca418b260
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

hidden-modules:       Database.PostgreSQL.LibPQ.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-libpq-0.9.4.3
library-dirs:
    /usr/lib/ghc-9.4.8/site-local/postgresql-libpq-0.9.4.3 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/postgresql-libpq-0.9.4.3 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/haskell-postgresql-libpq
hs-libraries:         HSpostgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
